<?php

namespace Drp\SimpleCms;

use InvalidArgumentException;

class ContentFactory implements \Drp\SimpleCms\Contracts\ContentFactory
{
    public function latestVersionByTypeAndContentId(string $contentType, int $contentId): Content
    {
        $contentClass = $this->makeContentClass($contentType);

        return $contentClass->getLatestVersionById($contentId);
    }

    public static function byTypeAndVersionId(string $contentType, int $versionId): Content
    {
        return self::makeContentClass($contentType)->findOrFail($versionId);
    }

    public static function makeContentClass(string $contentType): Content
    {
        return app(self::getContentClassName($contentType));
    }

    private static function getContentClassName(string $contentType): string
    {
        if (!array_key_exists($contentType, config('simple_cms.content_types'))) {
            throw new InvalidArgumentException(trans('simpleCms::content.errors.name-invalid'));
        }

        return array_get(config('simple_cms.content_types'), $contentType);
    }

    public static function contentLabel(string $contentType, ?bool $plural = null, ?bool $lowerCase = null): string
    {
        $content = self::makeContentClass($contentType);

        return $content->contentLabel($plural, $lowerCase);
    }
}
