<?php

namespace Drp\SimpleCms\Http\Controllers\Admin;

use Drp\SimpleCms\AllContent;
use Drp\SimpleCms\Contracts\ContentFactory;
use Drp\SimpleCms\Contracts\Publishable;
use Illuminate\Foundation\Auth\Access\AuthorizesRequests;
use Illuminate\Http\RedirectResponse;
use Illuminate\Routing\Controller;
use Illuminate\View\View;

class ReviewController extends Controller
{
    use AuthorizesRequests;

    /**
     * @var ContentFactory
     */
    private $contentFactory;

    public function __construct(ContentFactory $contentFactory)
    {
        $this->contentFactory = $contentFactory;
    }

    public function index(AllContent $allContent): View
    {
        $this->authorize('publish', Publishable::class);

        $content = $allContent->contentInReview();

        return view('simpleCms::review', compact('content'));
    }

    public function update(string $contentType, int $versionId): RedirectResponse
    {
        $content = $this->contentFactory->byTypeAndVersionId($contentType, $versionId);

        $this->authorize('review', $content);

        $content->updateReviewStatus();

        flash()->success(
            trans('simpleCms::content.' . ($content->isInReview() ? 'review-sent' : 'review-rejected'))
        );

        return redirect()->back();
    }
}
